==> notolog-1.0.2-py3-none-any.whl: notolog/lexemes/la/toolbar.py <==
# Latin lexemes toolbar.py
lexemes = {
    "actions_label_new_document": "Documentum novum",
    "actions_accessible_name_new_document": "Documentum novum",
    "actions_label_open": "Aperire",
    "actions_accessible_name_open": "Documentum aperire",
    "actions_label_save": "Salvare",
    "actions_accessible_name_save": "Documentum salvare",
    "actions_label_save_as": "Salvare ut",
    "actions_accessible_name_save_as": "Salvare ut exemplar documenti",
    "actions_label_sync": "Synchronizare",
    "actions_accessible_name_sync": "Documentum cum reposito externo synchronizare",
    "actions_label_edit": "Recensere",
    "actions_accessible_name_edit": "Fasciculum recensere",
    "actions_label_source": "Fons",
    "actions_accessible_name_source": "Codex",
    "actions_label_encrypt": "Codicare",
    "actions_accessible_name_encrypt": "Fasciculum codicare",
    "actions_label_decrypt": "Decodicare",
    "actions_accessible_name_decrypt": "Fasciculum decodicare",
    "actions_label_bold": "Audax",
    "actions_accessible_name_bold": "Formatum textus audax",
    "actions_label_italic": "Italicus",
    "actions_accessible_name_italic": "Formatum textus italicus",
    "actions_label_underline": "Sublineare",
    "actions_accessible_name_underline": "Formatum textus sublineare",
    "actions_label_strikethrough": "Exstinguere",
    "actions_accessible_name_strikethrough": "Formatum textus exstinguere",
    "actions_label_blockquote": "Blockquote",
    "actions_accessible_name_blockquote": "Formatum textus blockquote",
    "actions_label_color_picker": "Color selector",
    "actions_accessible_name_color_picker": "Elige colorem textus",
    "actions_label_ai_assistant": "Assistens AI",
    "actions_accessible_name_ai_assistant": "Assistentem AI exercere",
    "actions_label_about": "De",
    "actions_accessible_name_about": "De App",
    "actions_label_exit": "Exire",
    "actions_accessible_name_exit": "Exire App",
    "actions_label_settings": "Configurationes",
    "actions_accessible_name_settings": "Configurationes Applicatio",

    "search_input_label": "Quaerere",
    "search_input_placeholder_text": "textus in documento",
    "search_input_accessible_description": "Campus input quaerere",
    "search_buttons_label_clear": "Quaestionem purare",
    "search_buttons_accessible_name_clear": "Campum quaestionis purare",
    "search_buttons_label_prev": "Quaestio praecedens",
    "search_buttons_accessible_name_prev": "Eventus quaestionis praecedentis",
    "search_buttons_label_next": "Quaestio proxima",
    "search_buttons_accessible_name_next": "Eventus quaestionis proximae",
    "search_case_sensitive_label": "Casu sensitivo",
    "search_case_sensitive_tooltip": "Quaerere casu sensitivo",
}

==> notolog-1.0.7-py3-none-any.whl: notolog/lexemes/la/toolbar.py <==
# Latin lexemes toolbar.py
lexemes = {
    "actions_label_new_document": "Documentum novum",
    "actions_accessible_name_new_document": "Documentum novum",
    "actions_label_open": "Aperire",
    "actions_accessible_name_open": "Documentum aperire",
    "actions_label_save": "Salvare",
    "actions_accessible_name_save": "Documentum salvare",
    "actions_label_save_as": "Salvare ut",
    "actions_accessible_name_save_as": "Salvare ut exemplar documenti",
    "actions_label_sync": "Synchronizare",
    "actions_accessible_name_sync": "Documentum cum reposito externo synchronizare",
    "actions_label_edit": "Recensere",
    "actions_accessible_name_edit": "Fasciculum recensere",
    "actions_label_source": "Fons",
    "actions_accessible_name_source": "Codex",
    "actions_label_encrypt": "Codicare",
    "actions_accessible_name_encrypt": "Fasciculum codicare",
    "actions_label_decrypt": "Decodicare",
    "actions_accessible_name_decrypt": "Fasciculum decodicare",
    "actions_label_bold": "Audax",
    "actions_accessible_name_bold": "Formatum textus audax",
    "actions_label_italic": "Italicus",
    "actions_accessible_name_italic": "Formatum textus italicus",
    "actions_label_underline": "Sublineare",
    "actions_accessible_name_underline": "Formatum textus sublineare",
    "actions_label_strikethrough": "Exstinguere",
    "actions_accessible_name_strikethrough": "Formatum textus exstinguere",
    "actions_label_blockquote": "Blockquote",
    "actions_accessible_name_blockquote": "Formatum textus blockquote",
    "actions_label_color_picker": "Color selector",
    "actions_accessible_name_color_picker": "Elige colorem textus",
    "actions_label_ai_assistant": "Assistens AI",
    "actions_accessible_name_ai_assistant": "Assistentem AI exercere",
    "actions_label_about": "De",
    "actions_accessible_name_about": "De App",
    "actions_label_exit": "Exire",
    "actions_accessible_name_exit": "Exire App",
    "actions_label_settings": "Configurationes",
    "actions_accessible_name_settings": "Configurationes Applicatio",

    "search_input_label": "Quaerere",
    "search_input_placeholder_text": "Quaere textum in documento",
    "search_input_accessible_description": "Campus input quaerere",
    "search_buttons_label_clear": "Quaestionem purare",
    "search_buttons_accessible_name_clear": "Campum quaestionis purare",
    "search_buttons_label_prev": "Quaestio praecedens",
    "search_buttons_accessible_name_prev": "Eventus quaestionis praecedentis",
    "search_buttons_label_next": "Quaestio proxima",
    "search_buttons_accessible_name_next": "Eventus quaestionis proximae",
    "search_case_sensitive_accessible_name": "Casu sensitivo",
    "search_case_sensitive_tooltip": "Quaerere casu sensitivo",
}
